@@ -11,14 +11,31 @@
 #'
 #' @details
 #' This method needs to be implemented by the class that implement
-#' the Future API.  The implementation must never throw an error,
-#' but only return either TRUE or FALSE.
+#' the Future API.  The implementation should return either TRUE or FALSE
+#' and must never throw an error (except for [FutureError]:s which indicate
+#' significant, often unrecoverable infrastructure problems).
 #' It should also be possible to use the method for polling the
 #' future until it is resolved (without having to wait infinitely long),
 #' e.g. `while (!resolved(future)) Sys.sleep(5)`.
 #'
 #' @export
-resolved <- function(x, ...) UseMethod("resolved")
+resolved <- function(x, ...) {
+  ## Automatically update journal entries for Future object
+  if (inherits(future, "Future") &&
+      inherits(future$.journal, "FutureJournal")) {
+    start <- Sys.time()
+    on.exit({
+      appendToFutureJournal(x,
+        event = "resolved",
+        category = "querying",
+        start = start,
+        stop = Sys.time(),
+        skip = FALSE
+      )
+    })
+  }
+  UseMethod("resolved")
+}
 
 #' @export
 resolved.default <- function(x, ...) TRUE
